@@ -3,7 +3,7 @@
 # Crypt::HashCash::Client - Client for HashCash Digital Cash
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Client.pm v1.122 Thu Jun 15 19:09:16 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Client.pm v1.123 Mon Jun 19 15:07:46 PDT 2017 $
 
 package Crypt::HashCash::Client;
 
@@ -23,7 +23,7 @@ use Crypt::HashCash qw (_dec _hex);
 use Compress::Zlib;
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.122 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.123 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
@@ -247,7 +247,7 @@ sub AUTOLOAD {
   }
 }
 
-1;
+1; # End of Crypt::HashCash::Client
 
 __END__
 
@@ -257,8 +257,8 @@ Crypt::HashCash::Client - Client for HashCash Digital Cash
 
 =head1 VERSION
 
- $Revision: 1.122 $
- $Date: Thu Jun 15 19:09:16 PDT 2017 $
+ $Revision: 1.123 $
+ $Date: Mon Jun 19 15:07:46 PDT 2017 $
 
 =head1 SYNOPSIS
 
@@ -316,6 +316,20 @@ Creates and returns a new Crypt::HashCash::Client object.
 
 =head1 ACCESSORS
 
+=head1 SEE ALSO
+
+=head2 L<www.hashcash.com>
+
+=head2 L<Crypt::HashCash>
+
+=head2 L<Crypt::HashCash::Mint>
+
+=head2 L<Crypt::HashCash::Coin>
+
+=head2 L<Crypt::HashCash::Vault::Bitcoin>
+
+=head2 L<Business::HashCash>
+
 =head1 AUTHOR
 
 Ashish Gulhati, C<< <crypt-hashcash at hash.neo.tc> >>
