@@ -3,7 +3,7 @@
 # Crypt::HashCash::Mint - Mint for HashCash Digital Cash
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Mint.pm v1.122 Thu Jun 15 19:09:16 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Mint.pm v1.123 Mon Jun 19 15:07:46 PDT 2017 $
 
 package Crypt::HashCash::Mint;
 
@@ -18,7 +18,7 @@ use Persistence::Object::Simple;
 use vars qw( $VERSION $AUTOLOAD );
 use DBI;
 
-our ( $VERSION ) = '$Revision: 1.122 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.123 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
@@ -179,8 +179,8 @@ Crypt::HashCash::Mint - Mint for HashCash Digital Cash
 
 =head1 VERSION
 
- $Revision: 1.122 $
- $Date: Thu Jun 15 19:09:16 PDT 2017 $
+ $Revision: 1.123 $
+ $Date: Mon Jun 19 15:07:46 PDT 2017 $
 
 =head1 SYNOPSIS
 
@@ -244,6 +244,20 @@ Unspends the coin provided as the only argument. Returns undef if
 there was an error in the argument, 0 if the coin wasn't in the spent
 DB, or 1 if it was successfully unspent.
 
+=head1 SEE ALSO
+
+=head2 L<www.hashcash.com>
+
+=head2 L<Crypt::HashCash>
+
+=head2 L<Crypt::HashCash::Client>
+
+=head2 L<Crypt::HashCash::Coin>
+
+=head2 L<Crypt::HashCash::Vault::Bitcoin>
+
+=head2 L<Business::HashCash>
+
 =head1 AUTHOR
 
 Ashish Gulhati, C<< <crypt-hashcash at hash.neo.tc> >>
