@@ -3,7 +3,7 @@
 # Crypt::HashCash::Vault::Bitcoin - Bitcoin Vault for HashCash Digital Cash
 # Copyright (c) 2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Vault/Bitcoin.pm v1.122 Thu Jun 15 19:09:17 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Vault/Bitcoin.pm v1.123 Mon Jun 19 15:07:47 PDT 2017 $
 
 package Crypt::HashCash::Vault::Bitcoin;
 
@@ -20,7 +20,7 @@ use Business::Bitcoin;
 use Authen::TuringImage;
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.122 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.123 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my ($class, %arg) = @_;
@@ -470,8 +470,8 @@ Crypt::HashCash::Vault::Bitcoin - Bitcoin Vault for HashCash Digital Cash
 
 =head1 VERSION
 
- $Revision: 1.122 $
- $Date: Thu Jun 15 19:09:17 PDT 2017 $
+ $Revision: 1.123 $
+ $Date: Mon Jun 19 15:07:47 PDT 2017 $
 
 =head1 SYNOPSIS
 
@@ -544,6 +544,20 @@ Creates and returns a new Crypt::HashCash::Vault::Bitcoin object.
 
 =head2 process_request
 
+=head1 SEE ALSO
+
+=head2 L<www.hashcash.com>
+
+=head2 L<Crypt::HashCash>
+
+=head2 L<Crypt::HashCash::Mint>
+
+=head2 L<Crypt::HashCash::Client>
+
+=head2 L<Crypt::HashCash::Coin>
+
+=head2 L<Business::HashCash>
+
 =head1 AUTHOR
 
 Ashish Gulhati, C<< <crypt-hashcash at hash.neo.tc> >>
